build_transport

Function build_transport 

pub fn build_transport(
    keypair: &Keypair,
) -> Result<Boxed<(PeerId, StreamMuxerBox)>>
Builds the libp2p transport.

This function creates a TCP-based transport that is secured with Noise and multiplexed with Yamux.

Arguments

  • keypair - The identity::Keypair of the local node.

Errors

This function will return an error if the transport cannot be built.